translate.filters.checks.TeeChecker

Package translate :: Package filters :: Module checks :: Class TeeChecker |
[hide private]
[frames] | no frames]

# Class TeeChecker

source code

A Checker that controls multiple checkers.

Instance Methods | [hide private]
__init__(self, checkerconfig=None, excludefilters=None, limitfilters=None, checkerclasses=None, errorhandler=None, languagecode=None) construct a TeeChecker from the given checkers | source code
getfilters(self, excludefilters=None, limitfilters=None) returns dictionary of available filters, including/excluding those in the given lists | source code
run_filters(self, unit) run all the tests in the checker's suites | source code
setsuggestionstore(self, store) Sets the filename that a checker should use for evaluating suggestions. | source code